# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v1.proto.common.criteria_pb2 import (
    AgeRangeInfo as google___ads___googleads___v1___common___criteria_pb2___AgeRangeInfo,
    AppPaymentModelInfo as google___ads___googleads___v1___common___criteria_pb2___AppPaymentModelInfo,
    CustomAffinityInfo as google___ads___googleads___v1___common___criteria_pb2___CustomAffinityInfo,
    CustomIntentInfo as google___ads___googleads___v1___common___criteria_pb2___CustomIntentInfo,
    GenderInfo as google___ads___googleads___v1___common___criteria_pb2___GenderInfo,
    IncomeRangeInfo as google___ads___googleads___v1___common___criteria_pb2___IncomeRangeInfo,
    KeywordInfo as google___ads___googleads___v1___common___criteria_pb2___KeywordInfo,
    ListingGroupInfo as google___ads___googleads___v1___common___criteria_pb2___ListingGroupInfo,
    MobileAppCategoryInfo as google___ads___googleads___v1___common___criteria_pb2___MobileAppCategoryInfo,
    MobileApplicationInfo as google___ads___googleads___v1___common___criteria_pb2___MobileApplicationInfo,
    ParentalStatusInfo as google___ads___googleads___v1___common___criteria_pb2___ParentalStatusInfo,
    PlacementInfo as google___ads___googleads___v1___common___criteria_pb2___PlacementInfo,
    TopicInfo as google___ads___googleads___v1___common___criteria_pb2___TopicInfo,
    UserInterestInfo as google___ads___googleads___v1___common___criteria_pb2___UserInterestInfo,
    UserListInfo as google___ads___googleads___v1___common___criteria_pb2___UserListInfo,
    WebpageInfo as google___ads___googleads___v1___common___criteria_pb2___WebpageInfo,
    YouTubeChannelInfo as google___ads___googleads___v1___common___criteria_pb2___YouTubeChannelInfo,
    YouTubeVideoInfo as google___ads___googleads___v1___common___criteria_pb2___YouTubeVideoInfo,
)

from google.ads.google_ads.v1.proto.common.custom_parameter_pb2 import (
    CustomParameter as google___ads___googleads___v1___common___custom_parameter_pb2___CustomParameter,
)

from google.ads.google_ads.v1.proto.enums.ad_group_criterion_approval_status_pb2 import (
    AdGroupCriterionApprovalStatusEnum as google___ads___googleads___v1___enums___ad_group_criterion_approval_status_pb2___AdGroupCriterionApprovalStatusEnum,
)

from google.ads.google_ads.v1.proto.enums.ad_group_criterion_status_pb2 import (
    AdGroupCriterionStatusEnum as google___ads___googleads___v1___enums___ad_group_criterion_status_pb2___AdGroupCriterionStatusEnum,
)

from google.ads.google_ads.v1.proto.enums.bidding_source_pb2 import (
    BiddingSourceEnum as google___ads___googleads___v1___enums___bidding_source_pb2___BiddingSourceEnum,
)

from google.ads.google_ads.v1.proto.enums.criterion_system_serving_status_pb2 import (
    CriterionSystemServingStatusEnum as google___ads___googleads___v1___enums___criterion_system_serving_status_pb2___CriterionSystemServingStatusEnum,
)

from google.ads.google_ads.v1.proto.enums.criterion_type_pb2 import (
    CriterionTypeEnum as google___ads___googleads___v1___enums___criterion_type_pb2___CriterionTypeEnum,
)

from google.ads.google_ads.v1.proto.enums.quality_score_bucket_pb2 import (
    QualityScoreBucketEnum as google___ads___googleads___v1___enums___quality_score_bucket_pb2___QualityScoreBucketEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    BoolValue as google___protobuf___wrappers_pb2___BoolValue,
    DoubleValue as google___protobuf___wrappers_pb2___DoubleValue,
    Int32Value as google___protobuf___wrappers_pb2___Int32Value,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class AdGroupCriterion(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class QualityInfo(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        creative_quality_score = ... # type: google___ads___googleads___v1___enums___quality_score_bucket_pb2___QualityScoreBucketEnum.QualityScoreBucket
        post_click_quality_score = ... # type: google___ads___googleads___v1___enums___quality_score_bucket_pb2___QualityScoreBucketEnum.QualityScoreBucket
        search_predicted_ctr = ... # type: google___ads___googleads___v1___enums___quality_score_bucket_pb2___QualityScoreBucketEnum.QualityScoreBucket

        @property
        def quality_score(self) -> google___protobuf___wrappers_pb2___Int32Value: ...

        def __init__(self,
            *,
            quality_score : typing___Optional[google___protobuf___wrappers_pb2___Int32Value] = None,
            creative_quality_score : typing___Optional[google___ads___googleads___v1___enums___quality_score_bucket_pb2___QualityScoreBucketEnum.QualityScoreBucket] = None,
            post_click_quality_score : typing___Optional[google___ads___googleads___v1___enums___quality_score_bucket_pb2___QualityScoreBucketEnum.QualityScoreBucket] = None,
            search_predicted_ctr : typing___Optional[google___ads___googleads___v1___enums___quality_score_bucket_pb2___QualityScoreBucketEnum.QualityScoreBucket] = None,
            ) -> None: ...
        @classmethod
        def FromString(cls, s: bytes) -> AdGroupCriterion.QualityInfo: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        if sys.version_info >= (3,):
            def HasField(self, field_name: typing_extensions___Literal[u"quality_score"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"creative_quality_score",u"post_click_quality_score",u"quality_score",u"search_predicted_ctr"]) -> None: ...
        else:
            def HasField(self, field_name: typing_extensions___Literal[u"quality_score",b"quality_score"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"creative_quality_score",b"creative_quality_score",u"post_click_quality_score",b"post_click_quality_score",u"quality_score",b"quality_score",u"search_predicted_ctr",b"search_predicted_ctr"]) -> None: ...

    class PositionEstimates(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        @property
        def first_page_cpc_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

        @property
        def first_position_cpc_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

        @property
        def top_of_page_cpc_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

        @property
        def estimated_add_clicks_at_first_position_cpc(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

        @property
        def estimated_add_cost_at_first_position_cpc(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

        def __init__(self,
            *,
            first_page_cpc_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
            first_position_cpc_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
            top_of_page_cpc_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
            estimated_add_clicks_at_first_position_cpc : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
            estimated_add_cost_at_first_position_cpc : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
            ) -> None: ...
        @classmethod
        def FromString(cls, s: bytes) -> AdGroupCriterion.PositionEstimates: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        if sys.version_info >= (3,):
            def HasField(self, field_name: typing_extensions___Literal[u"estimated_add_clicks_at_first_position_cpc",u"estimated_add_cost_at_first_position_cpc",u"first_page_cpc_micros",u"first_position_cpc_micros",u"top_of_page_cpc_micros"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"estimated_add_clicks_at_first_position_cpc",u"estimated_add_cost_at_first_position_cpc",u"first_page_cpc_micros",u"first_position_cpc_micros",u"top_of_page_cpc_micros"]) -> None: ...
        else:
            def HasField(self, field_name: typing_extensions___Literal[u"estimated_add_clicks_at_first_position_cpc",b"estimated_add_clicks_at_first_position_cpc",u"estimated_add_cost_at_first_position_cpc",b"estimated_add_cost_at_first_position_cpc",u"first_page_cpc_micros",b"first_page_cpc_micros",u"first_position_cpc_micros",b"first_position_cpc_micros",u"top_of_page_cpc_micros",b"top_of_page_cpc_micros"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"estimated_add_clicks_at_first_position_cpc",b"estimated_add_clicks_at_first_position_cpc",u"estimated_add_cost_at_first_position_cpc",b"estimated_add_cost_at_first_position_cpc",u"first_page_cpc_micros",b"first_page_cpc_micros",u"first_position_cpc_micros",b"first_position_cpc_micros",u"top_of_page_cpc_micros",b"top_of_page_cpc_micros"]) -> None: ...

    resource_name = ... # type: typing___Text
    status = ... # type: google___ads___googleads___v1___enums___ad_group_criterion_status_pb2___AdGroupCriterionStatusEnum.AdGroupCriterionStatus
    type = ... # type: google___ads___googleads___v1___enums___criterion_type_pb2___CriterionTypeEnum.CriterionType
    system_serving_status = ... # type: google___ads___googleads___v1___enums___criterion_system_serving_status_pb2___CriterionSystemServingStatusEnum.CriterionSystemServingStatus
    approval_status = ... # type: google___ads___googleads___v1___enums___ad_group_criterion_approval_status_pb2___AdGroupCriterionApprovalStatusEnum.AdGroupCriterionApprovalStatus
    effective_cpc_bid_source = ... # type: google___ads___googleads___v1___enums___bidding_source_pb2___BiddingSourceEnum.BiddingSource
    effective_cpm_bid_source = ... # type: google___ads___googleads___v1___enums___bidding_source_pb2___BiddingSourceEnum.BiddingSource
    effective_cpv_bid_source = ... # type: google___ads___googleads___v1___enums___bidding_source_pb2___BiddingSourceEnum.BiddingSource
    effective_percent_cpc_bid_source = ... # type: google___ads___googleads___v1___enums___bidding_source_pb2___BiddingSourceEnum.BiddingSource

    @property
    def criterion_id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def quality_info(self) -> AdGroupCriterion.QualityInfo: ...

    @property
    def ad_group(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def negative(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

    @property
    def bid_modifier(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def cpc_bid_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def cpm_bid_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def cpv_bid_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def percent_cpc_bid_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def effective_cpc_bid_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def effective_cpm_bid_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def effective_cpv_bid_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def effective_percent_cpc_bid_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def position_estimates(self) -> AdGroupCriterion.PositionEstimates: ...

    @property
    def final_urls(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___StringValue]: ...

    @property
    def final_mobile_urls(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___StringValue]: ...

    @property
    def final_url_suffix(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def tracking_url_template(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def url_custom_parameters(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___ads___googleads___v1___common___custom_parameter_pb2___CustomParameter]: ...

    @property
    def keyword(self) -> google___ads___googleads___v1___common___criteria_pb2___KeywordInfo: ...

    @property
    def placement(self) -> google___ads___googleads___v1___common___criteria_pb2___PlacementInfo: ...

    @property
    def mobile_app_category(self) -> google___ads___googleads___v1___common___criteria_pb2___MobileAppCategoryInfo: ...

    @property
    def mobile_application(self) -> google___ads___googleads___v1___common___criteria_pb2___MobileApplicationInfo: ...

    @property
    def listing_group(self) -> google___ads___googleads___v1___common___criteria_pb2___ListingGroupInfo: ...

    @property
    def age_range(self) -> google___ads___googleads___v1___common___criteria_pb2___AgeRangeInfo: ...

    @property
    def gender(self) -> google___ads___googleads___v1___common___criteria_pb2___GenderInfo: ...

    @property
    def income_range(self) -> google___ads___googleads___v1___common___criteria_pb2___IncomeRangeInfo: ...

    @property
    def parental_status(self) -> google___ads___googleads___v1___common___criteria_pb2___ParentalStatusInfo: ...

    @property
    def user_list(self) -> google___ads___googleads___v1___common___criteria_pb2___UserListInfo: ...

    @property
    def youtube_video(self) -> google___ads___googleads___v1___common___criteria_pb2___YouTubeVideoInfo: ...

    @property
    def youtube_channel(self) -> google___ads___googleads___v1___common___criteria_pb2___YouTubeChannelInfo: ...

    @property
    def topic(self) -> google___ads___googleads___v1___common___criteria_pb2___TopicInfo: ...

    @property
    def user_interest(self) -> google___ads___googleads___v1___common___criteria_pb2___UserInterestInfo: ...

    @property
    def webpage(self) -> google___ads___googleads___v1___common___criteria_pb2___WebpageInfo: ...

    @property
    def app_payment_model(self) -> google___ads___googleads___v1___common___criteria_pb2___AppPaymentModelInfo: ...

    @property
    def custom_affinity(self) -> google___ads___googleads___v1___common___criteria_pb2___CustomAffinityInfo: ...

    @property
    def custom_intent(self) -> google___ads___googleads___v1___common___criteria_pb2___CustomIntentInfo: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        criterion_id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        status : typing___Optional[google___ads___googleads___v1___enums___ad_group_criterion_status_pb2___AdGroupCriterionStatusEnum.AdGroupCriterionStatus] = None,
        quality_info : typing___Optional[AdGroupCriterion.QualityInfo] = None,
        ad_group : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        type : typing___Optional[google___ads___googleads___v1___enums___criterion_type_pb2___CriterionTypeEnum.CriterionType] = None,
        negative : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        system_serving_status : typing___Optional[google___ads___googleads___v1___enums___criterion_system_serving_status_pb2___CriterionSystemServingStatusEnum.CriterionSystemServingStatus] = None,
        approval_status : typing___Optional[google___ads___googleads___v1___enums___ad_group_criterion_approval_status_pb2___AdGroupCriterionApprovalStatusEnum.AdGroupCriterionApprovalStatus] = None,
        bid_modifier : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        cpc_bid_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        cpm_bid_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        cpv_bid_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        percent_cpc_bid_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        effective_cpc_bid_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        effective_cpm_bid_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        effective_cpv_bid_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        effective_percent_cpc_bid_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        effective_cpc_bid_source : typing___Optional[google___ads___googleads___v1___enums___bidding_source_pb2___BiddingSourceEnum.BiddingSource] = None,
        effective_cpm_bid_source : typing___Optional[google___ads___googleads___v1___enums___bidding_source_pb2___BiddingSourceEnum.BiddingSource] = None,
        effective_cpv_bid_source : typing___Optional[google___ads___googleads___v1___enums___bidding_source_pb2___BiddingSourceEnum.BiddingSource] = None,
        effective_percent_cpc_bid_source : typing___Optional[google___ads___googleads___v1___enums___bidding_source_pb2___BiddingSourceEnum.BiddingSource] = None,
        position_estimates : typing___Optional[AdGroupCriterion.PositionEstimates] = None,
        final_urls : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___StringValue]] = None,
        final_mobile_urls : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___StringValue]] = None,
        final_url_suffix : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        tracking_url_template : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        url_custom_parameters : typing___Optional[typing___Iterable[google___ads___googleads___v1___common___custom_parameter_pb2___CustomParameter]] = None,
        keyword : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___KeywordInfo] = None,
        placement : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___PlacementInfo] = None,
        mobile_app_category : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___MobileAppCategoryInfo] = None,
        mobile_application : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___MobileApplicationInfo] = None,
        listing_group : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___ListingGroupInfo] = None,
        age_range : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___AgeRangeInfo] = None,
        gender : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___GenderInfo] = None,
        income_range : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___IncomeRangeInfo] = None,
        parental_status : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___ParentalStatusInfo] = None,
        user_list : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___UserListInfo] = None,
        youtube_video : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___YouTubeVideoInfo] = None,
        youtube_channel : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___YouTubeChannelInfo] = None,
        topic : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___TopicInfo] = None,
        user_interest : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___UserInterestInfo] = None,
        webpage : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___WebpageInfo] = None,
        app_payment_model : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___AppPaymentModelInfo] = None,
        custom_affinity : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___CustomAffinityInfo] = None,
        custom_intent : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___CustomIntentInfo] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AdGroupCriterion: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"ad_group",u"age_range",u"app_payment_model",u"bid_modifier",u"cpc_bid_micros",u"cpm_bid_micros",u"cpv_bid_micros",u"criterion",u"criterion_id",u"custom_affinity",u"custom_intent",u"effective_cpc_bid_micros",u"effective_cpm_bid_micros",u"effective_cpv_bid_micros",u"effective_percent_cpc_bid_micros",u"final_url_suffix",u"gender",u"income_range",u"keyword",u"listing_group",u"mobile_app_category",u"mobile_application",u"negative",u"parental_status",u"percent_cpc_bid_micros",u"placement",u"position_estimates",u"quality_info",u"topic",u"tracking_url_template",u"user_interest",u"user_list",u"webpage",u"youtube_channel",u"youtube_video"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_group",u"age_range",u"app_payment_model",u"approval_status",u"bid_modifier",u"cpc_bid_micros",u"cpm_bid_micros",u"cpv_bid_micros",u"criterion",u"criterion_id",u"custom_affinity",u"custom_intent",u"effective_cpc_bid_micros",u"effective_cpc_bid_source",u"effective_cpm_bid_micros",u"effective_cpm_bid_source",u"effective_cpv_bid_micros",u"effective_cpv_bid_source",u"effective_percent_cpc_bid_micros",u"effective_percent_cpc_bid_source",u"final_mobile_urls",u"final_url_suffix",u"final_urls",u"gender",u"income_range",u"keyword",u"listing_group",u"mobile_app_category",u"mobile_application",u"negative",u"parental_status",u"percent_cpc_bid_micros",u"placement",u"position_estimates",u"quality_info",u"resource_name",u"status",u"system_serving_status",u"topic",u"tracking_url_template",u"type",u"url_custom_parameters",u"user_interest",u"user_list",u"webpage",u"youtube_channel",u"youtube_video"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"ad_group",b"ad_group",u"age_range",b"age_range",u"app_payment_model",b"app_payment_model",u"bid_modifier",b"bid_modifier",u"cpc_bid_micros",b"cpc_bid_micros",u"cpm_bid_micros",b"cpm_bid_micros",u"cpv_bid_micros",b"cpv_bid_micros",u"criterion",b"criterion",u"criterion_id",b"criterion_id",u"custom_affinity",b"custom_affinity",u"custom_intent",b"custom_intent",u"effective_cpc_bid_micros",b"effective_cpc_bid_micros",u"effective_cpm_bid_micros",b"effective_cpm_bid_micros",u"effective_cpv_bid_micros",b"effective_cpv_bid_micros",u"effective_percent_cpc_bid_micros",b"effective_percent_cpc_bid_micros",u"final_url_suffix",b"final_url_suffix",u"gender",b"gender",u"income_range",b"income_range",u"keyword",b"keyword",u"listing_group",b"listing_group",u"mobile_app_category",b"mobile_app_category",u"mobile_application",b"mobile_application",u"negative",b"negative",u"parental_status",b"parental_status",u"percent_cpc_bid_micros",b"percent_cpc_bid_micros",u"placement",b"placement",u"position_estimates",b"position_estimates",u"quality_info",b"quality_info",u"topic",b"topic",u"tracking_url_template",b"tracking_url_template",u"user_interest",b"user_interest",u"user_list",b"user_list",u"webpage",b"webpage",u"youtube_channel",b"youtube_channel",u"youtube_video",b"youtube_video"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_group",b"ad_group",u"age_range",b"age_range",u"app_payment_model",b"app_payment_model",u"approval_status",b"approval_status",u"bid_modifier",b"bid_modifier",u"cpc_bid_micros",b"cpc_bid_micros",u"cpm_bid_micros",b"cpm_bid_micros",u"cpv_bid_micros",b"cpv_bid_micros",u"criterion",b"criterion",u"criterion_id",b"criterion_id",u"custom_affinity",b"custom_affinity",u"custom_intent",b"custom_intent",u"effective_cpc_bid_micros",b"effective_cpc_bid_micros",u"effective_cpc_bid_source",b"effective_cpc_bid_source",u"effective_cpm_bid_micros",b"effective_cpm_bid_micros",u"effective_cpm_bid_source",b"effective_cpm_bid_source",u"effective_cpv_bid_micros",b"effective_cpv_bid_micros",u"effective_cpv_bid_source",b"effective_cpv_bid_source",u"effective_percent_cpc_bid_micros",b"effective_percent_cpc_bid_micros",u"effective_percent_cpc_bid_source",b"effective_percent_cpc_bid_source",u"final_mobile_urls",b"final_mobile_urls",u"final_url_suffix",b"final_url_suffix",u"final_urls",b"final_urls",u"gender",b"gender",u"income_range",b"income_range",u"keyword",b"keyword",u"listing_group",b"listing_group",u"mobile_app_category",b"mobile_app_category",u"mobile_application",b"mobile_application",u"negative",b"negative",u"parental_status",b"parental_status",u"percent_cpc_bid_micros",b"percent_cpc_bid_micros",u"placement",b"placement",u"position_estimates",b"position_estimates",u"quality_info",b"quality_info",u"resource_name",b"resource_name",u"status",b"status",u"system_serving_status",b"system_serving_status",u"topic",b"topic",u"tracking_url_template",b"tracking_url_template",u"type",b"type",u"url_custom_parameters",b"url_custom_parameters",u"user_interest",b"user_interest",u"user_list",b"user_list",u"webpage",b"webpage",u"youtube_channel",b"youtube_channel",u"youtube_video",b"youtube_video"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"criterion",b"criterion"]) -> typing_extensions___Literal["keyword","placement","mobile_app_category","mobile_application","listing_group","age_range","gender","income_range","parental_status","user_list","youtube_video","youtube_channel","topic","user_interest","webpage","app_payment_model","custom_affinity","custom_intent"]: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v1.proto.enums.frequency_cap_event_type_pb2 import (
    FrequencyCapEventTypeEnum as google___ads___googleads___v1___enums___frequency_cap_event_type_pb2___FrequencyCapEventTypeEnum,
)

from google.ads.google_ads.v1.proto.enums.frequency_cap_level_pb2 import (
    FrequencyCapLevelEnum as google___ads___googleads___v1___enums___frequency_cap_level_pb2___FrequencyCapLevelEnum,
)

from google.ads.google_ads.v1.proto.enums.frequency_cap_time_unit_pb2 import (
    FrequencyCapTimeUnitEnum as google___ads___googleads___v1___enums___frequency_cap_time_unit_pb2___FrequencyCapTimeUnitEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    Int32Value as google___protobuf___wrappers_pb2___Int32Value,
)

from typing import (
    Optional as typing___Optional,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class FrequencyCapEntry(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def key(self) -> FrequencyCapKey: ...

    @property
    def cap(self) -> google___protobuf___wrappers_pb2___Int32Value: ...

    def __init__(self,
        *,
        key : typing___Optional[FrequencyCapKey] = None,
        cap : typing___Optional[google___protobuf___wrappers_pb2___Int32Value] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> FrequencyCapEntry: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"cap",u"key"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"cap",u"key"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"cap",b"cap",u"key",b"key"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"cap",b"cap",u"key",b"key"]) -> None: ...

class FrequencyCapKey(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    level = ... # type: google___ads___googleads___v1___enums___frequency_cap_level_pb2___FrequencyCapLevelEnum.FrequencyCapLevel
    event_type = ... # type: google___ads___googleads___v1___enums___frequency_cap_event_type_pb2___FrequencyCapEventTypeEnum.FrequencyCapEventType
    time_unit = ... # type: google___ads___googleads___v1___enums___frequency_cap_time_unit_pb2___FrequencyCapTimeUnitEnum.FrequencyCapTimeUnit

    @property
    def time_length(self) -> google___protobuf___wrappers_pb2___Int32Value: ...

    def __init__(self,
        *,
        level : typing___Optional[google___ads___googleads___v1___enums___frequency_cap_level_pb2___FrequencyCapLevelEnum.FrequencyCapLevel] = None,
        event_type : typing___Optional[google___ads___googleads___v1___enums___frequency_cap_event_type_pb2___FrequencyCapEventTypeEnum.FrequencyCapEventType] = None,
        time_unit : typing___Optional[google___ads___googleads___v1___enums___frequency_cap_time_unit_pb2___FrequencyCapTimeUnitEnum.FrequencyCapTimeUnit] = None,
        time_length : typing___Optional[google___protobuf___wrappers_pb2___Int32Value] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> FrequencyCapKey: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"time_length"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"event_type",u"level",u"time_length",u"time_unit"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"time_length",b"time_length"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"event_type",b"event_type",u"level",b"level",u"time_length",b"time_length",u"time_unit",b"time_unit"]) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class SearchTermMatchTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class SearchTermMatchType(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> SearchTermMatchTypeEnum.SearchTermMatchType: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[SearchTermMatchTypeEnum.SearchTermMatchType]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, SearchTermMatchTypeEnum.SearchTermMatchType]]: ...
        UNSPECIFIED = typing___cast(SearchTermMatchTypeEnum.SearchTermMatchType, 0)
        UNKNOWN = typing___cast(SearchTermMatchTypeEnum.SearchTermMatchType, 1)
        BROAD = typing___cast(SearchTermMatchTypeEnum.SearchTermMatchType, 2)
        EXACT = typing___cast(SearchTermMatchTypeEnum.SearchTermMatchType, 3)
        PHRASE = typing___cast(SearchTermMatchTypeEnum.SearchTermMatchType, 4)
        NEAR_EXACT = typing___cast(SearchTermMatchTypeEnum.SearchTermMatchType, 5)
        NEAR_PHRASE = typing___cast(SearchTermMatchTypeEnum.SearchTermMatchType, 6)
    UNSPECIFIED = typing___cast(SearchTermMatchTypeEnum.SearchTermMatchType, 0)
    UNKNOWN = typing___cast(SearchTermMatchTypeEnum.SearchTermMatchType, 1)
    BROAD = typing___cast(SearchTermMatchTypeEnum.SearchTermMatchType, 2)
    EXACT = typing___cast(SearchTermMatchTypeEnum.SearchTermMatchType, 3)
    PHRASE = typing___cast(SearchTermMatchTypeEnum.SearchTermMatchType, 4)
    NEAR_EXACT = typing___cast(SearchTermMatchTypeEnum.SearchTermMatchType, 5)
    NEAR_PHRASE = typing___cast(SearchTermMatchTypeEnum.SearchTermMatchType, 6)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> SearchTermMatchTypeEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# Stubs for google.ads.google_ads.v2.proto.services.bidding_strategy_service_pb2_grpc (Python 3)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

class BiddingStrategyServiceStub:
    GetBiddingStrategy: Any = ...
    MutateBiddingStrategies: Any = ...
    def __init__(self, channel: Any) -> None: ...

class BiddingStrategyServiceServicer:
    def GetBiddingStrategy(self, request: Any, context: Any) -> None: ...
    def MutateBiddingStrategies(self, request: Any, context: Any) -> None: ...

def add_BiddingStrategyServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class MultiplierErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class MultiplierError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> MultiplierErrorEnum.MultiplierError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[MultiplierErrorEnum.MultiplierError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, MultiplierErrorEnum.MultiplierError]]: ...
        UNSPECIFIED = typing___cast(MultiplierErrorEnum.MultiplierError, 0)
        UNKNOWN = typing___cast(MultiplierErrorEnum.MultiplierError, 1)
        MULTIPLIER_TOO_HIGH = typing___cast(MultiplierErrorEnum.MultiplierError, 2)
        MULTIPLIER_TOO_LOW = typing___cast(MultiplierErrorEnum.MultiplierError, 3)
        TOO_MANY_FRACTIONAL_DIGITS = typing___cast(MultiplierErrorEnum.MultiplierError, 4)
        MULTIPLIER_NOT_ALLOWED_FOR_BIDDING_STRATEGY = typing___cast(MultiplierErrorEnum.MultiplierError, 5)
        MULTIPLIER_NOT_ALLOWED_WHEN_BASE_BID_IS_MISSING = typing___cast(MultiplierErrorEnum.MultiplierError, 6)
        NO_MULTIPLIER_SPECIFIED = typing___cast(MultiplierErrorEnum.MultiplierError, 7)
        MULTIPLIER_CAUSES_BID_TO_EXCEED_DAILY_BUDGET = typing___cast(MultiplierErrorEnum.MultiplierError, 8)
        MULTIPLIER_CAUSES_BID_TO_EXCEED_MONTHLY_BUDGET = typing___cast(MultiplierErrorEnum.MultiplierError, 9)
        MULTIPLIER_CAUSES_BID_TO_EXCEED_CUSTOM_BUDGET = typing___cast(MultiplierErrorEnum.MultiplierError, 10)
        MULTIPLIER_CAUSES_BID_TO_EXCEED_MAX_ALLOWED_BID = typing___cast(MultiplierErrorEnum.MultiplierError, 11)
        BID_LESS_THAN_MIN_ALLOWED_BID_WITH_MULTIPLIER = typing___cast(MultiplierErrorEnum.MultiplierError, 12)
        MULTIPLIER_AND_BIDDING_STRATEGY_TYPE_MISMATCH = typing___cast(MultiplierErrorEnum.MultiplierError, 13)
    UNSPECIFIED = typing___cast(MultiplierErrorEnum.MultiplierError, 0)
    UNKNOWN = typing___cast(MultiplierErrorEnum.MultiplierError, 1)
    MULTIPLIER_TOO_HIGH = typing___cast(MultiplierErrorEnum.MultiplierError, 2)
    MULTIPLIER_TOO_LOW = typing___cast(MultiplierErrorEnum.MultiplierError, 3)
    TOO_MANY_FRACTIONAL_DIGITS = typing___cast(MultiplierErrorEnum.MultiplierError, 4)
    MULTIPLIER_NOT_ALLOWED_FOR_BIDDING_STRATEGY = typing___cast(MultiplierErrorEnum.MultiplierError, 5)
    MULTIPLIER_NOT_ALLOWED_WHEN_BASE_BID_IS_MISSING = typing___cast(MultiplierErrorEnum.MultiplierError, 6)
    NO_MULTIPLIER_SPECIFIED = typing___cast(MultiplierErrorEnum.MultiplierError, 7)
    MULTIPLIER_CAUSES_BID_TO_EXCEED_DAILY_BUDGET = typing___cast(MultiplierErrorEnum.MultiplierError, 8)
    MULTIPLIER_CAUSES_BID_TO_EXCEED_MONTHLY_BUDGET = typing___cast(MultiplierErrorEnum.MultiplierError, 9)
    MULTIPLIER_CAUSES_BID_TO_EXCEED_CUSTOM_BUDGET = typing___cast(MultiplierErrorEnum.MultiplierError, 10)
    MULTIPLIER_CAUSES_BID_TO_EXCEED_MAX_ALLOWED_BID = typing___cast(MultiplierErrorEnum.MultiplierError, 11)
    BID_LESS_THAN_MIN_ALLOWED_BID_WITH_MULTIPLIER = typing___cast(MultiplierErrorEnum.MultiplierError, 12)
    MULTIPLIER_AND_BIDDING_STRATEGY_TYPE_MISMATCH = typing___cast(MultiplierErrorEnum.MultiplierError, 13)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MultiplierErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class FeedItemQualityDisapprovalReasonEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class FeedItemQualityDisapprovalReason(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason]]: ...
        UNSPECIFIED = typing___cast(FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason, 0)
        UNKNOWN = typing___cast(FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason, 1)
        PRICE_TABLE_REPETITIVE_HEADERS = typing___cast(FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason, 2)
        PRICE_TABLE_REPETITIVE_DESCRIPTION = typing___cast(FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason, 3)
        PRICE_TABLE_INCONSISTENT_ROWS = typing___cast(FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason, 4)
        PRICE_DESCRIPTION_HAS_PRICE_QUALIFIERS = typing___cast(FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason, 5)
        PRICE_UNSUPPORTED_LANGUAGE = typing___cast(FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason, 6)
        PRICE_TABLE_ROW_HEADER_TABLE_TYPE_MISMATCH = typing___cast(FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason, 7)
        PRICE_TABLE_ROW_HEADER_HAS_PROMOTIONAL_TEXT = typing___cast(FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason, 8)
        PRICE_TABLE_ROW_DESCRIPTION_NOT_RELEVANT = typing___cast(FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason, 9)
        PRICE_TABLE_ROW_DESCRIPTION_HAS_PROMOTIONAL_TEXT = typing___cast(FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason, 10)
        PRICE_TABLE_ROW_HEADER_DESCRIPTION_REPETITIVE = typing___cast(FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason, 11)
        PRICE_TABLE_ROW_UNRATEABLE = typing___cast(FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason, 12)
        PRICE_TABLE_ROW_PRICE_INVALID = typing___cast(FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason, 13)
        PRICE_TABLE_ROW_URL_INVALID = typing___cast(FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason, 14)
        PRICE_HEADER_OR_DESCRIPTION_HAS_PRICE = typing___cast(FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason, 15)
        STRUCTURED_SNIPPETS_HEADER_POLICY_VIOLATED = typing___cast(FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason, 16)
        STRUCTURED_SNIPPETS_REPEATED_VALUES = typing___cast(FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason, 17)
        STRUCTURED_SNIPPETS_EDITORIAL_GUIDELINES = typing___cast(FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason, 18)
        STRUCTURED_SNIPPETS_HAS_PROMOTIONAL_TEXT = typing___cast(FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason, 19)
    UNSPECIFIED = typing___cast(FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason, 0)
    UNKNOWN = typing___cast(FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason, 1)
    PRICE_TABLE_REPETITIVE_HEADERS = typing___cast(FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason, 2)
    PRICE_TABLE_REPETITIVE_DESCRIPTION = typing___cast(FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason, 3)
    PRICE_TABLE_INCONSISTENT_ROWS = typing___cast(FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason, 4)
    PRICE_DESCRIPTION_HAS_PRICE_QUALIFIERS = typing___cast(FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason, 5)
    PRICE_UNSUPPORTED_LANGUAGE = typing___cast(FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason, 6)
    PRICE_TABLE_ROW_HEADER_TABLE_TYPE_MISMATCH = typing___cast(FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason, 7)
    PRICE_TABLE_ROW_HEADER_HAS_PROMOTIONAL_TEXT = typing___cast(FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason, 8)
    PRICE_TABLE_ROW_DESCRIPTION_NOT_RELEVANT = typing___cast(FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason, 9)
    PRICE_TABLE_ROW_DESCRIPTION_HAS_PROMOTIONAL_TEXT = typing___cast(FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason, 10)
    PRICE_TABLE_ROW_HEADER_DESCRIPTION_REPETITIVE = typing___cast(FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason, 11)
    PRICE_TABLE_ROW_UNRATEABLE = typing___cast(FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason, 12)
    PRICE_TABLE_ROW_PRICE_INVALID = typing___cast(FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason, 13)
    PRICE_TABLE_ROW_URL_INVALID = typing___cast(FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason, 14)
    PRICE_HEADER_OR_DESCRIPTION_HAS_PRICE = typing___cast(FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason, 15)
    STRUCTURED_SNIPPETS_HEADER_POLICY_VIOLATED = typing___cast(FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason, 16)
    STRUCTURED_SNIPPETS_REPEATED_VALUES = typing___cast(FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason, 17)
    STRUCTURED_SNIPPETS_EDITORIAL_GUIDELINES = typing___cast(FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason, 18)
    STRUCTURED_SNIPPETS_HAS_PROMOTIONAL_TEXT = typing___cast(FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason, 19)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> FeedItemQualityDisapprovalReasonEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class VanityPharmaTextEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class VanityPharmaText(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> VanityPharmaTextEnum.VanityPharmaText: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[VanityPharmaTextEnum.VanityPharmaText]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, VanityPharmaTextEnum.VanityPharmaText]]: ...
        UNSPECIFIED = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 0)
        UNKNOWN = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 1)
        PRESCRIPTION_TREATMENT_WEBSITE_EN = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 2)
        PRESCRIPTION_TREATMENT_WEBSITE_ES = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 3)
        PRESCRIPTION_DEVICE_WEBSITE_EN = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 4)
        PRESCRIPTION_DEVICE_WEBSITE_ES = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 5)
        MEDICAL_DEVICE_WEBSITE_EN = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 6)
        MEDICAL_DEVICE_WEBSITE_ES = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 7)
        PREVENTATIVE_TREATMENT_WEBSITE_EN = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 8)
        PREVENTATIVE_TREATMENT_WEBSITE_ES = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 9)
        PRESCRIPTION_CONTRACEPTION_WEBSITE_EN = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 10)
        PRESCRIPTION_CONTRACEPTION_WEBSITE_ES = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 11)
        PRESCRIPTION_VACCINE_WEBSITE_EN = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 12)
        PRESCRIPTION_VACCINE_WEBSITE_ES = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 13)
    UNSPECIFIED = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 0)
    UNKNOWN = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 1)
    PRESCRIPTION_TREATMENT_WEBSITE_EN = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 2)
    PRESCRIPTION_TREATMENT_WEBSITE_ES = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 3)
    PRESCRIPTION_DEVICE_WEBSITE_EN = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 4)
    PRESCRIPTION_DEVICE_WEBSITE_ES = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 5)
    MEDICAL_DEVICE_WEBSITE_EN = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 6)
    MEDICAL_DEVICE_WEBSITE_ES = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 7)
    PREVENTATIVE_TREATMENT_WEBSITE_EN = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 8)
    PREVENTATIVE_TREATMENT_WEBSITE_ES = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 9)
    PRESCRIPTION_CONTRACEPTION_WEBSITE_EN = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 10)
    PRESCRIPTION_CONTRACEPTION_WEBSITE_ES = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 11)
    PRESCRIPTION_VACCINE_WEBSITE_EN = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 12)
    PRESCRIPTION_VACCINE_WEBSITE_ES = typing___cast(VanityPharmaTextEnum.VanityPharmaText, 13)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> VanityPharmaTextEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class UrlCollection(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def url_collection_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def final_urls(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___StringValue]: ...

    @property
    def final_mobile_urls(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___StringValue]: ...

    @property
    def tracking_url_template(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        url_collection_id : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        final_urls : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___StringValue]] = None,
        final_mobile_urls : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___StringValue]] = None,
        tracking_url_template : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> UrlCollection: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"tracking_url_template",u"url_collection_id"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"final_mobile_urls",u"final_urls",u"tracking_url_template",u"url_collection_id"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"tracking_url_template",b"tracking_url_template",u"url_collection_id",b"url_collection_id"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"final_mobile_urls",b"final_mobile_urls",u"final_urls",b"final_urls",u"tracking_url_template",b"tracking_url_template",u"url_collection_id",b"url_collection_id"]) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    DoubleValue as google___protobuf___wrappers_pb2___DoubleValue,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from google.rpc.status_pb2 import (
    Status as google___rpc___status_pb2___Status,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class UploadClickConversionsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id = ... # type: typing___Text
    partial_failure = ... # type: bool
    validate_only = ... # type: bool

    @property
    def conversions(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[ClickConversion]: ...

    def __init__(self,
        *,
        customer_id : typing___Optional[typing___Text] = None,
        conversions : typing___Optional[typing___Iterable[ClickConversion]] = None,
        partial_failure : typing___Optional[bool] = None,
        validate_only : typing___Optional[bool] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> UploadClickConversionsRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"conversions",u"customer_id",u"partial_failure",u"validate_only"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"conversions",b"conversions",u"customer_id",b"customer_id",u"partial_failure",b"partial_failure",u"validate_only",b"validate_only"]) -> None: ...

class UploadClickConversionsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def partial_failure_error(self) -> google___rpc___status_pb2___Status: ...

    @property
    def results(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[ClickConversionResult]: ...

    def __init__(self,
        *,
        partial_failure_error : typing___Optional[google___rpc___status_pb2___Status] = None,
        results : typing___Optional[typing___Iterable[ClickConversionResult]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> UploadClickConversionsResponse: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"partial_failure_error"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"partial_failure_error",u"results"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"partial_failure_error",b"partial_failure_error"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"partial_failure_error",b"partial_failure_error",u"results",b"results"]) -> None: ...

class UploadCallConversionsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id = ... # type: typing___Text
    partial_failure = ... # type: bool
    validate_only = ... # type: bool

    @property
    def conversions(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[CallConversion]: ...

    def __init__(self,
        *,
        customer_id : typing___Optional[typing___Text] = None,
        conversions : typing___Optional[typing___Iterable[CallConversion]] = None,
        partial_failure : typing___Optional[bool] = None,
        validate_only : typing___Optional[bool] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> UploadCallConversionsRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"conversions",u"customer_id",u"partial_failure",u"validate_only"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"conversions",b"conversions",u"customer_id",b"customer_id",u"partial_failure",b"partial_failure",u"validate_only",b"validate_only"]) -> None: ...

class UploadCallConversionsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def partial_failure_error(self) -> google___rpc___status_pb2___Status: ...

    @property
    def results(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[CallConversionResult]: ...

    def __init__(self,
        *,
        partial_failure_error : typing___Optional[google___rpc___status_pb2___Status] = None,
        results : typing___Optional[typing___Iterable[CallConversionResult]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> UploadCallConversionsResponse: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"partial_failure_error"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"partial_failure_error",u"results"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"partial_failure_error",b"partial_failure_error"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"partial_failure_error",b"partial_failure_error",u"results",b"results"]) -> None: ...

class ClickConversion(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def gclid(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def conversion_action(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def conversion_date_time(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def conversion_value(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def currency_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def order_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def external_attribution_data(self) -> ExternalAttributionData: ...

    def __init__(self,
        *,
        gclid : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        conversion_action : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        conversion_date_time : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        conversion_value : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        currency_code : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        order_id : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        external_attribution_data : typing___Optional[ExternalAttributionData] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ClickConversion: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"conversion_action",u"conversion_date_time",u"conversion_value",u"currency_code",u"external_attribution_data",u"gclid",u"order_id"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"conversion_action",u"conversion_date_time",u"conversion_value",u"currency_code",u"external_attribution_data",u"gclid",u"order_id"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"conversion_action",b"conversion_action",u"conversion_date_time",b"conversion_date_time",u"conversion_value",b"conversion_value",u"currency_code",b"currency_code",u"external_attribution_data",b"external_attribution_data",u"gclid",b"gclid",u"order_id",b"order_id"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"conversion_action",b"conversion_action",u"conversion_date_time",b"conversion_date_time",u"conversion_value",b"conversion_value",u"currency_code",b"currency_code",u"external_attribution_data",b"external_attribution_data",u"gclid",b"gclid",u"order_id",b"order_id"]) -> None: ...

class CallConversion(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def caller_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def call_start_date_time(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def conversion_action(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def conversion_date_time(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def conversion_value(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def currency_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        caller_id : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        call_start_date_time : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        conversion_action : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        conversion_date_time : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        conversion_value : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        currency_code : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CallConversion: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"call_start_date_time",u"caller_id",u"conversion_action",u"conversion_date_time",u"conversion_value",u"currency_code"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"call_start_date_time",u"caller_id",u"conversion_action",u"conversion_date_time",u"conversion_value",u"currency_code"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"call_start_date_time",b"call_start_date_time",u"caller_id",b"caller_id",u"conversion_action",b"conversion_action",u"conversion_date_time",b"conversion_date_time",u"conversion_value",b"conversion_value",u"currency_code",b"currency_code"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"call_start_date_time",b"call_start_date_time",u"caller_id",b"caller_id",u"conversion_action",b"conversion_action",u"conversion_date_time",b"conversion_date_time",u"conversion_value",b"conversion_value",u"currency_code",b"currency_code"]) -> None: ...

class ExternalAttributionData(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def external_attribution_credit(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def external_attribution_model(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        external_attribution_credit : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        external_attribution_model : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ExternalAttributionData: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"external_attribution_credit",u"external_attribution_model"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"external_attribution_credit",u"external_attribution_model"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"external_attribution_credit",b"external_attribution_credit",u"external_attribution_model",b"external_attribution_model"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"external_attribution_credit",b"external_attribution_credit",u"external_attribution_model",b"external_attribution_model"]) -> None: ...

class ClickConversionResult(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def gclid(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def conversion_action(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def conversion_date_time(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        gclid : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        conversion_action : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        conversion_date_time : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ClickConversionResult: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"conversion_action",u"conversion_date_time",u"gclid"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"conversion_action",u"conversion_date_time",u"gclid"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"conversion_action",b"conversion_action",u"conversion_date_time",b"conversion_date_time",u"gclid",b"gclid"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"conversion_action",b"conversion_action",u"conversion_date_time",b"conversion_date_time",u"gclid",b"gclid"]) -> None: ...

class CallConversionResult(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def caller_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def call_start_date_time(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def conversion_action(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def conversion_date_time(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        caller_id : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        call_start_date_time : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        conversion_action : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        conversion_date_time : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CallConversionResult: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"call_start_date_time",u"caller_id",u"conversion_action",u"conversion_date_time"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"call_start_date_time",u"caller_id",u"conversion_action",u"conversion_date_time"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"call_start_date_time",b"call_start_date_time",u"caller_id",b"caller_id",u"conversion_action",b"conversion_action",u"conversion_date_time",b"conversion_date_time"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"call_start_date_time",b"call_start_date_time",u"caller_id",b"caller_id",u"conversion_action",b"conversion_action",u"conversion_date_time",b"conversion_date_time"]) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class AdTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class AdType(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> AdTypeEnum.AdType: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[AdTypeEnum.AdType]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, AdTypeEnum.AdType]]: ...
        UNSPECIFIED = typing___cast(AdTypeEnum.AdType, 0)
        UNKNOWN = typing___cast(AdTypeEnum.AdType, 1)
        TEXT_AD = typing___cast(AdTypeEnum.AdType, 2)
        EXPANDED_TEXT_AD = typing___cast(AdTypeEnum.AdType, 3)
        CALL_ONLY_AD = typing___cast(AdTypeEnum.AdType, 6)
        EXPANDED_DYNAMIC_SEARCH_AD = typing___cast(AdTypeEnum.AdType, 7)
        HOTEL_AD = typing___cast(AdTypeEnum.AdType, 8)
        SHOPPING_SMART_AD = typing___cast(AdTypeEnum.AdType, 9)
        SHOPPING_PRODUCT_AD = typing___cast(AdTypeEnum.AdType, 10)
        VIDEO_AD = typing___cast(AdTypeEnum.AdType, 12)
        GMAIL_AD = typing___cast(AdTypeEnum.AdType, 13)
        IMAGE_AD = typing___cast(AdTypeEnum.AdType, 14)
        RESPONSIVE_SEARCH_AD = typing___cast(AdTypeEnum.AdType, 15)
        LEGACY_RESPONSIVE_DISPLAY_AD = typing___cast(AdTypeEnum.AdType, 16)
        APP_AD = typing___cast(AdTypeEnum.AdType, 17)
        LEGACY_APP_INSTALL_AD = typing___cast(AdTypeEnum.AdType, 18)
        RESPONSIVE_DISPLAY_AD = typing___cast(AdTypeEnum.AdType, 19)
        HTML5_UPLOAD_AD = typing___cast(AdTypeEnum.AdType, 21)
        DYNAMIC_HTML5_AD = typing___cast(AdTypeEnum.AdType, 22)
        APP_ENGAGEMENT_AD = typing___cast(AdTypeEnum.AdType, 23)
        SHOPPING_COMPARISON_LISTING_AD = typing___cast(AdTypeEnum.AdType, 24)
    UNSPECIFIED = typing___cast(AdTypeEnum.AdType, 0)
    UNKNOWN = typing___cast(AdTypeEnum.AdType, 1)
    TEXT_AD = typing___cast(AdTypeEnum.AdType, 2)
    EXPANDED_TEXT_AD = typing___cast(AdTypeEnum.AdType, 3)
    CALL_ONLY_AD = typing___cast(AdTypeEnum.AdType, 6)
    EXPANDED_DYNAMIC_SEARCH_AD = typing___cast(AdTypeEnum.AdType, 7)
    HOTEL_AD = typing___cast(AdTypeEnum.AdType, 8)
    SHOPPING_SMART_AD = typing___cast(AdTypeEnum.AdType, 9)
    SHOPPING_PRODUCT_AD = typing___cast(AdTypeEnum.AdType, 10)
    VIDEO_AD = typing___cast(AdTypeEnum.AdType, 12)
    GMAIL_AD = typing___cast(AdTypeEnum.AdType, 13)
    IMAGE_AD = typing___cast(AdTypeEnum.AdType, 14)
    RESPONSIVE_SEARCH_AD = typing___cast(AdTypeEnum.AdType, 15)
    LEGACY_RESPONSIVE_DISPLAY_AD = typing___cast(AdTypeEnum.AdType, 16)
    APP_AD = typing___cast(AdTypeEnum.AdType, 17)
    LEGACY_APP_INSTALL_AD = typing___cast(AdTypeEnum.AdType, 18)
    RESPONSIVE_DISPLAY_AD = typing___cast(AdTypeEnum.AdType, 19)
    HTML5_UPLOAD_AD = typing___cast(AdTypeEnum.AdType, 21)
    DYNAMIC_HTML5_AD = typing___cast(AdTypeEnum.AdType, 22)
    APP_ENGAGEMENT_AD = typing___cast(AdTypeEnum.AdType, 23)
    SHOPPING_COMPARISON_LISTING_AD = typing___cast(AdTypeEnum.AdType, 24)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AdTypeEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.common.dates_pb2 import (
    DateRange as google___ads___googleads___v2___common___dates_pb2___DateRange,
)

from google.ads.google_ads.v2.proto.enums.keyword_plan_forecast_interval_pb2 import (
    KeywordPlanForecastIntervalEnum as google___ads___googleads___v2___enums___keyword_plan_forecast_interval_pb2___KeywordPlanForecastIntervalEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class KeywordPlan(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text

    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def name(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def forecast_period(self) -> KeywordPlanForecastPeriod: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        name : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        forecast_period : typing___Optional[KeywordPlanForecastPeriod] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> KeywordPlan: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"forecast_period",u"id",u"name"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"forecast_period",u"id",u"name",u"resource_name"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"forecast_period",b"forecast_period",u"id",b"id",u"name",b"name"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"forecast_period",b"forecast_period",u"id",b"id",u"name",b"name",u"resource_name",b"resource_name"]) -> None: ...

class KeywordPlanForecastPeriod(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    date_interval = ... # type: google___ads___googleads___v2___enums___keyword_plan_forecast_interval_pb2___KeywordPlanForecastIntervalEnum.KeywordPlanForecastInterval

    @property
    def date_range(self) -> google___ads___googleads___v2___common___dates_pb2___DateRange: ...

    def __init__(self,
        *,
        date_interval : typing___Optional[google___ads___googleads___v2___enums___keyword_plan_forecast_interval_pb2___KeywordPlanForecastIntervalEnum.KeywordPlanForecastInterval] = None,
        date_range : typing___Optional[google___ads___googleads___v2___common___dates_pb2___DateRange] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> KeywordPlanForecastPeriod: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"date_interval",u"date_range",u"interval"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"date_interval",u"date_range",u"interval"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"date_interval",b"date_interval",u"date_range",b"date_range",u"interval",b"interval"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"date_interval",b"date_interval",u"date_range",b"date_range",u"interval",b"interval"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"interval",b"interval"]) -> typing_extensions___Literal["date_interval","date_range"]: ...



# Stubs for google.ads.google_ads.v2.proto.enums.customer_pay_per_conversion_eligibility_failure_reason_pb2_grpc (Python 3)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.




# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class AuthenticationErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class AuthenticationError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> AuthenticationErrorEnum.AuthenticationError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[AuthenticationErrorEnum.AuthenticationError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, AuthenticationErrorEnum.AuthenticationError]]: ...
        UNSPECIFIED = typing___cast(AuthenticationErrorEnum.AuthenticationError, 0)
        UNKNOWN = typing___cast(AuthenticationErrorEnum.AuthenticationError, 1)
        AUTHENTICATION_ERROR = typing___cast(AuthenticationErrorEnum.AuthenticationError, 2)
        CLIENT_CUSTOMER_ID_INVALID = typing___cast(AuthenticationErrorEnum.AuthenticationError, 5)
        CUSTOMER_NOT_FOUND = typing___cast(AuthenticationErrorEnum.AuthenticationError, 8)
        GOOGLE_ACCOUNT_DELETED = typing___cast(AuthenticationErrorEnum.AuthenticationError, 9)
        GOOGLE_ACCOUNT_COOKIE_INVALID = typing___cast(AuthenticationErrorEnum.AuthenticationError, 10)
        GOOGLE_ACCOUNT_AUTHENTICATION_FAILED = typing___cast(AuthenticationErrorEnum.AuthenticationError, 25)
        GOOGLE_ACCOUNT_USER_AND_ADS_USER_MISMATCH = typing___cast(AuthenticationErrorEnum.AuthenticationError, 12)
        LOGIN_COOKIE_REQUIRED = typing___cast(AuthenticationErrorEnum.AuthenticationError, 13)
        NOT_ADS_USER = typing___cast(AuthenticationErrorEnum.AuthenticationError, 14)
        OAUTH_TOKEN_INVALID = typing___cast(AuthenticationErrorEnum.AuthenticationError, 15)
        OAUTH_TOKEN_EXPIRED = typing___cast(AuthenticationErrorEnum.AuthenticationError, 16)
        OAUTH_TOKEN_DISABLED = typing___cast(AuthenticationErrorEnum.AuthenticationError, 17)
        OAUTH_TOKEN_REVOKED = typing___cast(AuthenticationErrorEnum.AuthenticationError, 18)
        OAUTH_TOKEN_HEADER_INVALID = typing___cast(AuthenticationErrorEnum.AuthenticationError, 19)
        LOGIN_COOKIE_INVALID = typing___cast(AuthenticationErrorEnum.AuthenticationError, 20)
        USER_ID_INVALID = typing___cast(AuthenticationErrorEnum.AuthenticationError, 22)
        TWO_STEP_VERIFICATION_NOT_ENROLLED = typing___cast(AuthenticationErrorEnum.AuthenticationError, 23)
        ADVANCED_PROTECTION_NOT_ENROLLED = typing___cast(AuthenticationErrorEnum.AuthenticationError, 24)
    UNSPECIFIED = typing___cast(AuthenticationErrorEnum.AuthenticationError, 0)
    UNKNOWN = typing___cast(AuthenticationErrorEnum.AuthenticationError, 1)
    AUTHENTICATION_ERROR = typing___cast(AuthenticationErrorEnum.AuthenticationError, 2)
    CLIENT_CUSTOMER_ID_INVALID = typing___cast(AuthenticationErrorEnum.AuthenticationError, 5)
    CUSTOMER_NOT_FOUND = typing___cast(AuthenticationErrorEnum.AuthenticationError, 8)
    GOOGLE_ACCOUNT_DELETED = typing___cast(AuthenticationErrorEnum.AuthenticationError, 9)
    GOOGLE_ACCOUNT_COOKIE_INVALID = typing___cast(AuthenticationErrorEnum.AuthenticationError, 10)
    GOOGLE_ACCOUNT_AUTHENTICATION_FAILED = typing___cast(AuthenticationErrorEnum.AuthenticationError, 25)
    GOOGLE_ACCOUNT_USER_AND_ADS_USER_MISMATCH = typing___cast(AuthenticationErrorEnum.AuthenticationError, 12)
    LOGIN_COOKIE_REQUIRED = typing___cast(AuthenticationErrorEnum.AuthenticationError, 13)
    NOT_ADS_USER = typing___cast(AuthenticationErrorEnum.AuthenticationError, 14)
    OAUTH_TOKEN_INVALID = typing___cast(AuthenticationErrorEnum.AuthenticationError, 15)
    OAUTH_TOKEN_EXPIRED = typing___cast(AuthenticationErrorEnum.AuthenticationError, 16)
    OAUTH_TOKEN_DISABLED = typing___cast(AuthenticationErrorEnum.AuthenticationError, 17)
    OAUTH_TOKEN_REVOKED = typing___cast(AuthenticationErrorEnum.AuthenticationError, 18)
    OAUTH_TOKEN_HEADER_INVALID = typing___cast(AuthenticationErrorEnum.AuthenticationError, 19)
    LOGIN_COOKIE_INVALID = typing___cast(AuthenticationErrorEnum.AuthenticationError, 20)
    USER_ID_INVALID = typing___cast(AuthenticationErrorEnum.AuthenticationError, 22)
    TWO_STEP_VERIFICATION_NOT_ENROLLED = typing___cast(AuthenticationErrorEnum.AuthenticationError, 23)
    ADVANCED_PROTECTION_NOT_ENROLLED = typing___cast(AuthenticationErrorEnum.AuthenticationError, 24)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AuthenticationErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# Stubs for google.ads.google_ads.v1.services.transports.campaign_draft_service_grpc_transport (Python 3)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any, Optional

class CampaignDraftServiceGrpcTransport:
    def __init__(self, channel: Optional[Any] = ..., credentials: Optional[Any] = ..., address: str = ...) -> None: ...
    @classmethod
    def create_channel(cls, address: str = ..., credentials: Optional[Any] = ..., **kwargs: Any): ...
    @property
    def channel(self): ...
    @property
    def get_campaign_draft(self): ...
    @property
    def mutate_campaign_drafts(self): ...
    @property
    def promote_campaign_draft(self): ...
    @property
    def list_campaign_draft_async_errors(self): ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class DateErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class DateError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> DateErrorEnum.DateError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[DateErrorEnum.DateError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, DateErrorEnum.DateError]]: ...
        UNSPECIFIED = typing___cast(DateErrorEnum.DateError, 0)
        UNKNOWN = typing___cast(DateErrorEnum.DateError, 1)
        INVALID_FIELD_VALUES_IN_DATE = typing___cast(DateErrorEnum.DateError, 2)
        INVALID_FIELD_VALUES_IN_DATE_TIME = typing___cast(DateErrorEnum.DateError, 3)
        INVALID_STRING_DATE = typing___cast(DateErrorEnum.DateError, 4)
        INVALID_STRING_DATE_TIME_MICROS = typing___cast(DateErrorEnum.DateError, 6)
        INVALID_STRING_DATE_TIME_SECONDS = typing___cast(DateErrorEnum.DateError, 11)
        INVALID_STRING_DATE_TIME_SECONDS_WITH_OFFSET = typing___cast(DateErrorEnum.DateError, 12)
        EARLIER_THAN_MINIMUM_DATE = typing___cast(DateErrorEnum.DateError, 7)
        LATER_THAN_MAXIMUM_DATE = typing___cast(DateErrorEnum.DateError, 8)
        DATE_RANGE_MINIMUM_DATE_LATER_THAN_MAXIMUM_DATE = typing___cast(DateErrorEnum.DateError, 9)
        DATE_RANGE_MINIMUM_AND_MAXIMUM_DATES_BOTH_NULL = typing___cast(DateErrorEnum.DateError, 10)
    UNSPECIFIED = typing___cast(DateErrorEnum.DateError, 0)
    UNKNOWN = typing___cast(DateErrorEnum.DateError, 1)
    INVALID_FIELD_VALUES_IN_DATE = typing___cast(DateErrorEnum.DateError, 2)
    INVALID_FIELD_VALUES_IN_DATE_TIME = typing___cast(DateErrorEnum.DateError, 3)
    INVALID_STRING_DATE = typing___cast(DateErrorEnum.DateError, 4)
    INVALID_STRING_DATE_TIME_MICROS = typing___cast(DateErrorEnum.DateError, 6)
    INVALID_STRING_DATE_TIME_SECONDS = typing___cast(DateErrorEnum.DateError, 11)
    INVALID_STRING_DATE_TIME_SECONDS_WITH_OFFSET = typing___cast(DateErrorEnum.DateError, 12)
    EARLIER_THAN_MINIMUM_DATE = typing___cast(DateErrorEnum.DateError, 7)
    LATER_THAN_MAXIMUM_DATE = typing___cast(DateErrorEnum.DateError, 8)
    DATE_RANGE_MINIMUM_DATE_LATER_THAN_MAXIMUM_DATE = typing___cast(DateErrorEnum.DateError, 9)
    DATE_RANGE_MINIMUM_AND_MAXIMUM_DATES_BOTH_NULL = typing___cast(DateErrorEnum.DateError, 10)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> DateErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.common.criteria_pb2 import (
    InteractionTypeInfo as google___ads___googleads___v2___common___criteria_pb2___InteractionTypeInfo,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    DoubleValue as google___protobuf___wrappers_pb2___DoubleValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class CampaignBidModifier(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text

    @property
    def campaign(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def criterion_id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def bid_modifier(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def interaction_type(self) -> google___ads___googleads___v2___common___criteria_pb2___InteractionTypeInfo: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        campaign : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        criterion_id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        bid_modifier : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        interaction_type : typing___Optional[google___ads___googleads___v2___common___criteria_pb2___InteractionTypeInfo] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CampaignBidModifier: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"bid_modifier",u"campaign",u"criterion",u"criterion_id",u"interaction_type"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"bid_modifier",u"campaign",u"criterion",u"criterion_id",u"interaction_type",u"resource_name"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"bid_modifier",b"bid_modifier",u"campaign",b"campaign",u"criterion",b"criterion",u"criterion_id",b"criterion_id",u"interaction_type",b"interaction_type"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"bid_modifier",b"bid_modifier",u"campaign",b"campaign",u"criterion",b"criterion",u"criterion_id",b"criterion_id",u"interaction_type",b"interaction_type",u"resource_name",b"resource_name"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"criterion",b"criterion"]) -> typing_extensions___Literal["interaction_type"]: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class AgeRangeView(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AgeRangeView: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name",b"resource_name"]) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.common.custom_parameter_pb2 import (
    CustomParameter as google___ads___googleads___v2___common___custom_parameter_pb2___CustomParameter,
)

from google.ads.google_ads.v2.proto.common.feed_common_pb2 import (
    Money as google___ads___googleads___v2___common___feed_common_pb2___Money,
)

from google.ads.google_ads.v2.proto.enums.app_store_pb2 import (
    AppStoreEnum as google___ads___googleads___v2___enums___app_store_pb2___AppStoreEnum,
)

from google.ads.google_ads.v2.proto.enums.call_conversion_reporting_state_pb2 import (
    CallConversionReportingStateEnum as google___ads___googleads___v2___enums___call_conversion_reporting_state_pb2___CallConversionReportingStateEnum,
)

from google.ads.google_ads.v2.proto.enums.price_extension_price_qualifier_pb2 import (
    PriceExtensionPriceQualifierEnum as google___ads___googleads___v2___enums___price_extension_price_qualifier_pb2___PriceExtensionPriceQualifierEnum,
)

from google.ads.google_ads.v2.proto.enums.price_extension_price_unit_pb2 import (
    PriceExtensionPriceUnitEnum as google___ads___googleads___v2___enums___price_extension_price_unit_pb2___PriceExtensionPriceUnitEnum,
)

from google.ads.google_ads.v2.proto.enums.price_extension_type_pb2 import (
    PriceExtensionTypeEnum as google___ads___googleads___v2___enums___price_extension_type_pb2___PriceExtensionTypeEnum,
)

from google.ads.google_ads.v2.proto.enums.promotion_extension_discount_modifier_pb2 import (
    PromotionExtensionDiscountModifierEnum as google___ads___googleads___v2___enums___promotion_extension_discount_modifier_pb2___PromotionExtensionDiscountModifierEnum,
)

from google.ads.google_ads.v2.proto.enums.promotion_extension_occasion_pb2 import (
    PromotionExtensionOccasionEnum as google___ads___googleads___v2___enums___promotion_extension_occasion_pb2___PromotionExtensionOccasionEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    BoolValue as google___protobuf___wrappers_pb2___BoolValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    overload as typing___overload,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class AppFeedItem(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    app_store = ... # type: google___ads___googleads___v2___enums___app_store_pb2___AppStoreEnum.AppStore

    @property
    def link_text(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def app_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def final_urls(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___StringValue]: ...

    @property
    def final_mobile_urls(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___StringValue]: ...

    @property
    def tracking_url_template(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def url_custom_parameters(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___ads___googleads___v2___common___custom_parameter_pb2___CustomParameter]: ...

    @property
    def final_url_suffix(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        link_text : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        app_id : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        app_store : typing___Optional[google___ads___googleads___v2___enums___app_store_pb2___AppStoreEnum.AppStore] = None,
        final_urls : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___StringValue]] = None,
        final_mobile_urls : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___StringValue]] = None,
        tracking_url_template : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        url_custom_parameters : typing___Optional[typing___Iterable[google___ads___googleads___v2___common___custom_parameter_pb2___CustomParameter]] = None,
        final_url_suffix : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AppFeedItem: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"app_id",u"final_url_suffix",u"link_text",u"tracking_url_template"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"app_id",u"app_store",u"final_mobile_urls",u"final_url_suffix",u"final_urls",u"link_text",u"tracking_url_template",u"url_custom_parameters"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"app_id",b"app_id",u"final_url_suffix",b"final_url_suffix",u"link_text",b"link_text",u"tracking_url_template",b"tracking_url_template"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"app_id",b"app_id",u"app_store",b"app_store",u"final_mobile_urls",b"final_mobile_urls",u"final_url_suffix",b"final_url_suffix",u"final_urls",b"final_urls",u"link_text",b"link_text",u"tracking_url_template",b"tracking_url_template",u"url_custom_parameters",b"url_custom_parameters"]) -> None: ...

class CallFeedItem(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    call_conversion_reporting_state = ... # type: google___ads___googleads___v2___enums___call_conversion_reporting_state_pb2___CallConversionReportingStateEnum.CallConversionReportingState

    @property
    def phone_number(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def country_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def call_tracking_enabled(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

    @property
    def call_conversion_action(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def call_conversion_tracking_disabled(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

    def __init__(self,
        *,
        phone_number : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        country_code : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        call_tracking_enabled : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        call_conversion_action : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        call_conversion_tracking_disabled : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        call_conversion_reporting_state : typing___Optional[google___ads___googleads___v2___enums___call_conversion_reporting_state_pb2___CallConversionReportingStateEnum.CallConversionReportingState] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CallFeedItem: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"call_conversion_action",u"call_conversion_tracking_disabled",u"call_tracking_enabled",u"country_code",u"phone_number"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"call_conversion_action",u"call_conversion_reporting_state",u"call_conversion_tracking_disabled",u"call_tracking_enabled",u"country_code",u"phone_number"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"call_conversion_action",b"call_conversion_action",u"call_conversion_tracking_disabled",b"call_conversion_tracking_disabled",u"call_tracking_enabled",b"call_tracking_enabled",u"country_code",b"country_code",u"phone_number",b"phone_number"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"call_conversion_action",b"call_conversion_action",u"call_conversion_reporting_state",b"call_conversion_reporting_state",u"call_conversion_tracking_disabled",b"call_conversion_tracking_disabled",u"call_tracking_enabled",b"call_tracking_enabled",u"country_code",b"country_code",u"phone_number",b"phone_number"]) -> None: ...

class CalloutFeedItem(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def callout_text(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        callout_text : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CalloutFeedItem: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"callout_text"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"callout_text"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"callout_text",b"callout_text"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"callout_text",b"callout_text"]) -> None: ...

class LocationFeedItem(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def business_name(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def address_line_1(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def address_line_2(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def city(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def province(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def postal_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def country_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def phone_number(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        business_name : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        address_line_1 : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        address_line_2 : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        city : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        province : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        postal_code : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        country_code : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        phone_number : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> LocationFeedItem: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"address_line_1",u"address_line_2",u"business_name",u"city",u"country_code",u"phone_number",u"postal_code",u"province"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"address_line_1",u"address_line_2",u"business_name",u"city",u"country_code",u"phone_number",u"postal_code",u"province"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"address_line_1",b"address_line_1",u"address_line_2",b"address_line_2",u"business_name",b"business_name",u"city",b"city",u"country_code",b"country_code",u"phone_number",b"phone_number",u"postal_code",b"postal_code",u"province",b"province"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"address_line_1",b"address_line_1",u"address_line_2",b"address_line_2",u"business_name",b"business_name",u"city",b"city",u"country_code",b"country_code",u"phone_number",b"phone_number",u"postal_code",b"postal_code",u"province",b"province"]) -> None: ...

class AffiliateLocationFeedItem(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def business_name(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def address_line_1(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def address_line_2(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def city(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def province(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def postal_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def country_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def phone_number(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def chain_id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def chain_name(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        business_name : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        address_line_1 : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        address_line_2 : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        city : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        province : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        postal_code : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        country_code : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        phone_number : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        chain_id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        chain_name : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AffiliateLocationFeedItem: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"address_line_1",u"address_line_2",u"business_name",u"chain_id",u"chain_name",u"city",u"country_code",u"phone_number",u"postal_code",u"province"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"address_line_1",u"address_line_2",u"business_name",u"chain_id",u"chain_name",u"city",u"country_code",u"phone_number",u"postal_code",u"province"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"address_line_1",b"address_line_1",u"address_line_2",b"address_line_2",u"business_name",b"business_name",u"chain_id",b"chain_id",u"chain_name",b"chain_name",u"city",b"city",u"country_code",b"country_code",u"phone_number",b"phone_number",u"postal_code",b"postal_code",u"province",b"province"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"address_line_1",b"address_line_1",u"address_line_2",b"address_line_2",u"business_name",b"business_name",u"chain_id",b"chain_id",u"chain_name",b"chain_name",u"city",b"city",u"country_code",b"country_code",u"phone_number",b"phone_number",u"postal_code",b"postal_code",u"province",b"province"]) -> None: ...

class TextMessageFeedItem(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def business_name(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def country_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def phone_number(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def text(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def extension_text(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        business_name : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        country_code : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        phone_number : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        text : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        extension_text : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> TextMessageFeedItem: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"business_name",u"country_code",u"extension_text",u"phone_number",u"text"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"business_name",u"country_code",u"extension_text",u"phone_number",u"text"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"business_name",b"business_name",u"country_code",b"country_code",u"extension_text",b"extension_text",u"phone_number",b"phone_number",u"text",b"text"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"business_name",b"business_name",u"country_code",b"country_code",u"extension_text",b"extension_text",u"phone_number",b"phone_number",u"text",b"text"]) -> None: ...

class PriceFeedItem(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    type = ... # type: google___ads___googleads___v2___enums___price_extension_type_pb2___PriceExtensionTypeEnum.PriceExtensionType
    price_qualifier = ... # type: google___ads___googleads___v2___enums___price_extension_price_qualifier_pb2___PriceExtensionPriceQualifierEnum.PriceExtensionPriceQualifier

    @property
    def tracking_url_template(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def language_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def price_offerings(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[PriceOffer]: ...

    @property
    def final_url_suffix(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        type : typing___Optional[google___ads___googleads___v2___enums___price_extension_type_pb2___PriceExtensionTypeEnum.PriceExtensionType] = None,
        price_qualifier : typing___Optional[google___ads___googleads___v2___enums___price_extension_price_qualifier_pb2___PriceExtensionPriceQualifierEnum.PriceExtensionPriceQualifier] = None,
        tracking_url_template : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        language_code : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        price_offerings : typing___Optional[typing___Iterable[PriceOffer]] = None,
        final_url_suffix : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> PriceFeedItem: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"final_url_suffix",u"language_code",u"tracking_url_template"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"final_url_suffix",u"language_code",u"price_offerings",u"price_qualifier",u"tracking_url_template",u"type"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"final_url_suffix",b"final_url_suffix",u"language_code",b"language_code",u"tracking_url_template",b"tracking_url_template"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"final_url_suffix",b"final_url_suffix",u"language_code",b"language_code",u"price_offerings",b"price_offerings",u"price_qualifier",b"price_qualifier",u"tracking_url_template",b"tracking_url_template",u"type",b"type"]) -> None: ...

class PriceOffer(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    unit = ... # type: google___ads___googleads___v2___enums___price_extension_price_unit_pb2___PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit

    @property
    def header(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def description(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def price(self) -> google___ads___googleads___v2___common___feed_common_pb2___Money: ...

    @property
    def final_urls(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___StringValue]: ...

    @property
    def final_mobile_urls(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___StringValue]: ...

    def __init__(self,
        *,
        header : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        description : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        price : typing___Optional[google___ads___googleads___v2___common___feed_common_pb2___Money] = None,
        unit : typing___Optional[google___ads___googleads___v2___enums___price_extension_price_unit_pb2___PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit] = None,
        final_urls : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___StringValue]] = None,
        final_mobile_urls : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___StringValue]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> PriceOffer: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"description",u"header",u"price"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"description",u"final_mobile_urls",u"final_urls",u"header",u"price",u"unit"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"description",b"description",u"header",b"header",u"price",b"price"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"description",b"description",u"final_mobile_urls",b"final_mobile_urls",u"final_urls",b"final_urls",u"header",b"header",u"price",b"price",u"unit",b"unit"]) -> None: ...

class PromotionFeedItem(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    discount_modifier = ... # type: google___ads___googleads___v2___enums___promotion_extension_discount_modifier_pb2___PromotionExtensionDiscountModifierEnum.PromotionExtensionDiscountModifier
    occasion = ... # type: google___ads___googleads___v2___enums___promotion_extension_occasion_pb2___PromotionExtensionOccasionEnum.PromotionExtensionOccasion

    @property
    def promotion_target(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def promotion_start_date(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def promotion_end_date(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def final_urls(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___StringValue]: ...

    @property
    def final_mobile_urls(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___StringValue]: ...

    @property
    def tracking_url_template(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def url_custom_parameters(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___ads___googleads___v2___common___custom_parameter_pb2___CustomParameter]: ...

    @property
    def final_url_suffix(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def language_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def percent_off(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def money_amount_off(self) -> google___ads___googleads___v2___common___feed_common_pb2___Money: ...

    @property
    def promotion_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def orders_over_amount(self) -> google___ads___googleads___v2___common___feed_common_pb2___Money: ...

    def __init__(self,
        *,
        promotion_target : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        discount_modifier : typing___Optional[google___ads___googleads___v2___enums___promotion_extension_discount_modifier_pb2___PromotionExtensionDiscountModifierEnum.PromotionExtensionDiscountModifier] = None,
        promotion_start_date : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        promotion_end_date : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        occasion : typing___Optional[google___ads___googleads___v2___enums___promotion_extension_occasion_pb2___PromotionExtensionOccasionEnum.PromotionExtensionOccasion] = None,
        final_urls : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___StringValue]] = None,
        final_mobile_urls : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___StringValue]] = None,
        tracking_url_template : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        url_custom_parameters : typing___Optional[typing___Iterable[google___ads___googleads___v2___common___custom_parameter_pb2___CustomParameter]] = None,
        final_url_suffix : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        language_code : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        percent_off : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        money_amount_off : typing___Optional[google___ads___googleads___v2___common___feed_common_pb2___Money] = None,
        promotion_code : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        orders_over_amount : typing___Optional[google___ads___googleads___v2___common___feed_common_pb2___Money] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> PromotionFeedItem: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"discount_type",u"final_url_suffix",u"language_code",u"money_amount_off",u"orders_over_amount",u"percent_off",u"promotion_code",u"promotion_end_date",u"promotion_start_date",u"promotion_target",u"promotion_trigger",u"tracking_url_template"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"discount_modifier",u"discount_type",u"final_mobile_urls",u"final_url_suffix",u"final_urls",u"language_code",u"money_amount_off",u"occasion",u"orders_over_amount",u"percent_off",u"promotion_code",u"promotion_end_date",u"promotion_start_date",u"promotion_target",u"promotion_trigger",u"tracking_url_template",u"url_custom_parameters"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"discount_type",b"discount_type",u"final_url_suffix",b"final_url_suffix",u"language_code",b"language_code",u"money_amount_off",b"money_amount_off",u"orders_over_amount",b"orders_over_amount",u"percent_off",b"percent_off",u"promotion_code",b"promotion_code",u"promotion_end_date",b"promotion_end_date",u"promotion_start_date",b"promotion_start_date",u"promotion_target",b"promotion_target",u"promotion_trigger",b"promotion_trigger",u"tracking_url_template",b"tracking_url_template"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"discount_modifier",b"discount_modifier",u"discount_type",b"discount_type",u"final_mobile_urls",b"final_mobile_urls",u"final_url_suffix",b"final_url_suffix",u"final_urls",b"final_urls",u"language_code",b"language_code",u"money_amount_off",b"money_amount_off",u"occasion",b"occasion",u"orders_over_amount",b"orders_over_amount",u"percent_off",b"percent_off",u"promotion_code",b"promotion_code",u"promotion_end_date",b"promotion_end_date",u"promotion_start_date",b"promotion_start_date",u"promotion_target",b"promotion_target",u"promotion_trigger",b"promotion_trigger",u"tracking_url_template",b"tracking_url_template",u"url_custom_parameters",b"url_custom_parameters"]) -> None: ...
    @typing___overload
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"discount_type",b"discount_type"]) -> typing_extensions___Literal["percent_off","money_amount_off"]: ...
    @typing___overload
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"promotion_trigger",b"promotion_trigger"]) -> typing_extensions___Literal["promotion_code","orders_over_amount"]: ...

class StructuredSnippetFeedItem(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def header(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def values(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___StringValue]: ...

    def __init__(self,
        *,
        header : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        values : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___StringValue]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> StructuredSnippetFeedItem: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"header"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"header",u"values"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"header",b"header"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"header",b"header",u"values",b"values"]) -> None: ...

class SitelinkFeedItem(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def link_text(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def line1(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def line2(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def final_urls(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___StringValue]: ...

    @property
    def final_mobile_urls(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___StringValue]: ...

    @property
    def tracking_url_template(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def url_custom_parameters(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___ads___googleads___v2___common___custom_parameter_pb2___CustomParameter]: ...

    @property
    def final_url_suffix(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        link_text : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        line1 : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        line2 : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        final_urls : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___StringValue]] = None,
        final_mobile_urls : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___StringValue]] = None,
        tracking_url_template : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        url_custom_parameters : typing___Optional[typing___Iterable[google___ads___googleads___v2___common___custom_parameter_pb2___CustomParameter]] = None,
        final_url_suffix : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> SitelinkFeedItem: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"final_url_suffix",u"line1",u"line2",u"link_text",u"tracking_url_template"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"final_mobile_urls",u"final_url_suffix",u"final_urls",u"line1",u"line2",u"link_text",u"tracking_url_template",u"url_custom_parameters"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"final_url_suffix",b"final_url_suffix",u"line1",b"line1",u"line2",b"line2",u"link_text",b"link_text",u"tracking_url_template",b"tracking_url_template"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"final_mobile_urls",b"final_mobile_urls",u"final_url_suffix",b"final_url_suffix",u"final_urls",b"final_urls",u"line1",b"line1",u"line2",b"line2",u"link_text",b"link_text",u"tracking_url_template",b"tracking_url_template",u"url_custom_parameters",b"url_custom_parameters"]) -> None: ...

class HotelCalloutFeedItem(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def text(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def language_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        text : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        language_code : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> HotelCalloutFeedItem: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"language_code",u"text"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"language_code",u"text"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"language_code",b"language_code",u"text",b"text"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"language_code",b"language_code",u"text",b"text"]) -> None: ...
